@@ -26,7 +26,7 @@ except:
 	_c = False
 
 __all__ = ['status']
-__version__ = '3.4.6'
+__version__ = '3.5.5'
 
 if hasattr(_sys, 'runningPPF'):
 	PyProtFramework = True
@@ -1466,31 +1466,70 @@ class ProgressBar(Progress, BarWidget):
 @addBuiltins
 class VersionString(str):
 	def __init__(self, *args, **kwargs):
-		str.__init__(self, *args, **kwargs)
+		str.__init__(self)
 		try:
 			ver = self.split('.')
 			try:
-				self.major = ver[0]
+				self.major = int(ver[0])
 			except:
 				self.major = None
 			try:
-				self.minor = ver[1]
+				self.minor = int(ver[1])
 			except:
 				self.minor = None
 			try:
-				self.micro = ver[2]
+				self.micro = int(ver[2])
 			except:
 				self.micro = None
 		except: pass
 
+	def upgrade(self, target='default', maxMinor=9, maxMicro=9):
+		if target == 'default':
+			if self.micro is not None:
+				target = 'micro'
+			elif self.minor is not None:
+				target = 'minor'
+			elif self.major is not None:
+				target = 'major'
+		if self.micro is not None and self.micro >= maxMicro:
+			minor = True
+		else:
+			minor = False
+		if self.minor is not None and self.minor >= maxMinor:
+			major = True
+		else:
+			major = False
+		if True:
+			print(f'target: {str(target)}')
+			print(f'self.micro: {str(self.micro)}')
+			print(f'maxMicro: {str(maxMicro)}')
+			print(f'self.minor: {str(self.minor)}')
+			print(f'maxMinor: {str(maxMinor)}')
+			print(f'minor: {str(minor)}')
+			print(f'self.major: {str(self.major)}')
+			print(f'major: {str(major)}')
+		if self.micro is not None and target == 'micro' and not (minor or major):
+			self.micro += 1
+		if self.minor is not None and (target == 'minor' or minor) and not major:
+			if self.micro is not None:
+				self.micro = 0
+			self.minor += 1
+		if self.major is not None and (target == 'major' or major) and not minor:
+			if self.micro is not None:
+				self.micro = 0
+			if self.minor is not None:
+				self.minor = 0
+			self.major += 1
+		return self.compile()
+
 	def compile(self):
 		ver = []
-		if self.major:
-			ver.append(self.major)
-		if self.minor:
-			ver.append(self.minor)
-		if self.micro:
-			ver.append(self.micro)
+		if self.major is not None:
+			ver.append(str(self.major))
+		if self.minor is not None:
+			ver.append(str(self.minor))
+		if self.micro is not None:
+			ver.append(str(self.micro))
 		return '.'.join(ver)
 
 
